<?php
/**
* 饹Υեȥ
*
* PHP version 5
*
* @package    core
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/
require_once( 'FrameworkClassLoader.class.php' );

class ClassLoader
{
	var $_loaders;

	/*
	 *    󥹥ȥ饯
	 */
	private function __construct()
	{
		$this->_loaders = array();
	}

	/*
	 *    ͣΥ󥹥󥹼
	 */
	public static function &getInstance()
	{
		static $singleton_;
		if ( $singleton_ == null ){
			$singleton_ = new ClassLoader();
		}
		return $singleton_;
	}

	/*
	 * 饹ɲ
	 */
	public static function addClassLoader( IClassLoader $loader )
	{
		// 󥹥󥹤μ
		$ins = & self::getInstance();

		$ins->_loaders[] = $loader;
	}

	/*
	 * 饹
	 */
	public static function loadClass( $class_name )
	{
		// ե졼饹
		if ( FrameworkClassLoader::loadClass( $class_name ) ){
			return TRUE;
		}

		// 󥹥󥹤μ
		$ins = & self::getInstance();

		// 饹֤˸ƤӽФ
		foreach( $ins->_loaders as $loader ){
			if ( $loader->loadClass(s($class_name)) ){
				return TRUE;
			}
		}

		return FALSE;
	}
}
return __FILE__;